Index: pkg/analyzer_cli/bin/analyzer.dart |
diff --git a/pkg/analyzer_cli/bin/analyzer.dart b/pkg/analyzer_cli/bin/analyzer.dart |
index b0a32feee9eabf0503e2c5bdc853349d12530738..3172b0fab730f9adbc26652bfc058dcb5d13936a 100644 |
--- a/pkg/analyzer_cli/bin/analyzer.dart |
+++ b/pkg/analyzer_cli/bin/analyzer.dart |
@@ -3,14 +3,10 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-import 'package:analyzer_cli/src/driver.dart'; |
+import 'package:analyzer_cli/starter.dart'; |
- |
- |
- |
-/// The entry point for the analyzer. |
+/// The entry point for the command-line analyzer. |
void main(List<String> args) { |
- var starter = new Driver(); |
+ CommandLineStarter starter = new CommandLineStarter(); |
starter.start(args); |
- |
} |